@@ -423,12 +423,16 @@ class EventMonitor(ViewportPlugin):
     '''
     x, y = textview.window_to_buffer_coords(gtk.TextWindowType.WIDGET,
                                              int(event.x), int(event.y))
+    isText = True
     iter = textview.get_iter_at_location(x, y)
+    if isinstance(iter, tuple):
+        (isText, iter) = iter
     cursor = gdk.Cursor(gdk.CursorType.XTERM)
-    for tag in iter.get_tags():
-      if getattr(tag, 'islink'):
-        cursor = gdk.Cursor(gdk.CursorType.HAND2)
-        break
+    if isText:
+      for tag in iter.get_tags():
+        if getattr(tag, 'islink'):
+          cursor = gdk.Cursor(gdk.CursorType.HAND2)
+          break
     window = textview.get_window(gtk.TextWindowType.TEXT)
     window.set_cursor(cursor)
     window.get_pointer()
