@@ -15,6 +15,7 @@ import gi
 
 from gi.repository import Gtk as gtk
 from gi.repository import GdkPixbuf
+from gi.repository import Pango
 from gi.repository.GLib import markup_escape_text
 
 import pyatspi
@@ -319,11 +320,9 @@ class _SectionAccessible(_InterfaceSection):
     # preset the different bg colors
     style = self.relations_view.get_style_context()
     self.header_bg = style.get_background_color(gtk.StateFlags.NORMAL).to_string()
-    self.relation_bg = style.get_color(gtk.StateFlags.NORMAL).to_string()
+    self.relation_bg = style.get_background_color(gtk.StateFlags.NORMAL).to_string()
 
     selection = self.relations_view.get_selection()
-    selection.set_select_function(self._relationSelectFunc, None)
-
     show_button = ui_xml.get_object('button_relation_show')
     show_button.set_sensitive(self._isSelectedInView(selection))
     selection.connect('changed', self._onViewSelectionChanged, show_button)
@@ -345,7 +344,7 @@ class _SectionAccessible(_InterfaceSection):
     if 'accessibleId' in dir(acc) and acc.accessibleId:
         self.id_label.set_label(acc.accessibleId)
     else:
-        self.id_label.set_label(_('(no id)'))
+        self.id_label.set_label(_('(no ID)'))
 
     states = [pyatspi.stateToString(s) for s in acc.getState().getStates()]
     states.sort()
@@ -411,7 +410,7 @@ class _SectionAccessible(_InterfaceSection):
     '''
     selection = relations_view.get_selection()
     model, iter = selection.get_selected()
-    if iter:
+    if iter and model[iter][2] >= 0:
       path = model.get_path(iter)
       relations = self.node.acc.getRelationSet()
       acc = relations[path[0]].getTarget(model[iter][2])
@@ -1208,6 +1207,14 @@ class _SectionText(_InterfaceSection):
 
     self.offset_spin = ui_xml.get_object('spinbutton_text_offset')
     self.text_view = ui_xml.get_object('textview_text')
+    pango_ctx = self.text_view.get_pango_context()
+    for f in pango_ctx.list_families():
+        name = f.get_name()
+        # These are known to show e.g U+FFFC
+        if name in [ "Courier New", "Liberation Sans" ]:
+            self.text_view.modify_font(Pango.FontDescription(name))
+            break
+
     self.text_buffer = self.text_view.get_buffer()
     self.toggle_defaults = ui_xml.get_object('checkbutton_text_defaults')
     self.label_start = ui_xml.get_object('label_text_attr_start')
