@@ -68,7 +68,7 @@ class AccessibleModel(gtk.TreeStore, ToolsAccessor):
     Connects required signals.
     '''
     self.acc_cache = [desktop_acc]
-    gtk.TreeStore.__init__(self, GdkPixbuf.Pixbuf, str, str, str, bool, bool, object)
+    gtk.TreeStore.__init__(self, GdkPixbuf.Pixbuf, str, str, int, bool, bool, object)
     self.connect('row-changed', self._onRowChanged)
     self.connect('row-filled', self._onRowFilled)
     self.desktop = desktop_acc
@@ -453,11 +453,11 @@ class AccessibleModel(gtk.TreeStore, ToolsAccessor):
       if self.isMyApp(accessible):
         name = "Accerciser"
         role = "accerciser"
-        count = "0"
+        count = 0
       else:
         name = accessible.name
         role = accessible.getLocalizedRoleName()
-        count = str(accessible.childCount)
+        count = accessible.childCount
     else:
       icon = None
       if not dummy:
@@ -465,7 +465,7 @@ class AccessibleModel(gtk.TreeStore, ToolsAccessor):
       else:
         name = None
       role = None
-      count = None
+      count = 0
     return [icon, name, role, count, False, dummy, accessible]
 
 class AccessibleTreeView(gtk.TreeView, ToolsAccessor):
@@ -563,7 +563,7 @@ class AccessibleTreeView(gtk.TreeView, ToolsAccessor):
         ('RefreshCurrent', gtk.STOCK_JUMP_TO, _('Refresh _Node'),
         # Translators: Appears as tooltip
         #
-         None, _('Refresh selected node\'s children'), 
+         None, _('Refresh selected node’s children'), 
          self._refreshCurrentLevel)])  
 
     self.refresh_current_action = self.action_group.get_action('RefreshCurrent')
@@ -571,6 +571,7 @@ class AccessibleTreeView(gtk.TreeView, ToolsAccessor):
 
     self.connect('popup-menu', self._onPopup)
     self.connect('button-press-event', self._onPopup)
+    self.connect('key-press-event', self._onKeyPress)
 
     self.connect('cursor-changed', self._onCursorChanged)
 
@@ -582,6 +583,27 @@ class AccessibleTreeView(gtk.TreeView, ToolsAccessor):
     path = self.get_cursor()[0]
     self.refresh_current_action.set_sensitive(path is not None)      
 
+  def _onKeyPress(self, w, event):
+    '''
+    Expand or collapse a row on Left/Right key-press
+    '''
+    if event.state & \
+        (gdk.ModifierType.SHIFT_MASK
+        |gdk.ModifierType.CONTROL_MASK
+        |gdk.ModifierType.MOD1_MASK) == 0:
+      path, col = self.get_cursor()
+      if path is not None:
+        if event.keyval == gdk.KEY_Left:
+          if not self.collapse_row(path):
+            # if we ccouldn't collapse the current row, collapse the parent
+            if path.up():
+              self.collapse_row(path)
+          return True
+        elif event.keyval == gdk.KEY_Right:
+          self.expand_row(path, False)
+          return True
+    return False
+
   def _onPopup(self, w, event=None):
     '''
     Callback for popup button or right mouse button. Brings up a context
@@ -707,7 +729,7 @@ class AccessibleTreeView(gtk.TreeView, ToolsAccessor):
         elif event.type.minor == 'remove':
           self._removeChild(iter, event.source)
       if iter and self.model.iter_is_valid(iter):
-        self.model[iter][COL_CHILDCOUNT] = str(event.source.childCount)
+        self.model[iter][COL_CHILDCOUNT] = event.source.childCount
 
   def removeLeaves(self, accessibles):
     '''
@@ -790,14 +812,22 @@ class AccessibleTreeView(gtk.TreeView, ToolsAccessor):
       iter = self.model.iter_children(parent_iter)
     else:
       iter = self.model.get_iter_first()
+
     while iter:
       if self.model[iter][COL_ACC] not in parent:
+        cursor_path = self.get_cursor()[0]
+        if cursor_path != None:
+          iter_path = self.model.get_path(iter)
+          if iter_path.is_ancestor(cursor_path):
+            cursor_path = iter_path
+          if 0 == iter_path.compare(cursor_path):
+            if iter_path.prev() or iter_path.up():
+              self.set_cursor(iter_path, None, False)
         if not self.model.remove(iter):
           break
       else:
         iter = self.model.iter_next(iter)
 
-
   def _refreshChildren(self, iter):
     '''
     Remove all of a given node's children from the model.
@@ -813,7 +843,7 @@ class AccessibleTreeView(gtk.TreeView, ToolsAccessor):
       if not self.model.remove(child_iter):
         break
     acc = self.model[iter][COL_ACC]
-    self.model[iter][COL_CHILDCOUNT] = str(acc.childCount)
+    self.model[iter][COL_CHILDCOUNT] = acc.childCount
     self.model[iter][COL_FILLED] = False
 
   def refreshSelected(self):
